(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Wednesday 20 August 03 17:35:25 tews@debian>
 *
 * Typechecking with unification
 *
 * $Id: newtypecheck.mli,v 1.4 2003/08/21 15:15:02 tews Exp $
 *
 *)

open Classtypes
;;


(* val ccsl_typecheck_class_pass : Classtypes.ccsl_ast list -> unit *)

val ccsl_resolution_typecheck_pass : Classtypes.ccsl_ast list -> unit

(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

